#!/usr/bin/env python-i

from summon.core import *
from summon import shapes
import summon

import random


class Blob (object):
    def __init__(self, x, y, size):
        self.x =  x
        self.y = y
        self.size = size
        self.connects = set()
    
    def connect(self, other):
        self.connects.add(other)
        other.connects.add(self)   


class Food (Blob):
    def __init__(self, x, y, size, col=summon.green):
        Blob.__init__(self, x, y, size)
        self.color = col
        self.vis = None
        self.changed = True
        
    
    def draw(self):
        self.vis = translate(self.x, self.y, self.color, 
                             shapes.regular_polygon(0, 0, 6, self.size),
                             hotspot("click",
                                     self.x - self.size,
                                     self.y - self.size,
                                     self.x + self.size,
                                     self.y + self.size,
                                     self.onClick))
        return self.vis
        
    def update(self, win):
        self.vis = win.replace_group(self.vis, self.draw())
    
    
    def onClick(self):
        pass


class Player (object):
    def __init__(self, x, y, size, col=summon.red):
        self.color = col
        self.vis = None
        self.blobs = [PlayerBlob(self, x, y, size)]
        self.cursor = self.blobs[0]


class PlayerBlob (Blob):
    def __init__(self, player, x, y, size):
        Blob.__init__(self, x, y, size)        
        self.player = player

    def draw(self):
        self.vis = translate(self.x, self.y, self.player.color, 
                             shapes.regular_polygon(0, 0, 6, self.size))
        return self.vis

    def update(self, win):
        self.vis = win.replace_group(self.vis, self.draw())



class EatGame (summon.VisObject):
    def __init__(self):
        summon.VisObject.__init__(self)
        
        self.food = []
        self.players = []
        self.width = 10000
        self.height = 10000
        
        
        self.initFood(1000)
        self.initPlayers(1)
        self.mainPlayer = self.players[0]
        
    
    def initFood(self, nfood):
        self.food = []
        
        for i in xrange(nfood):
            x = self.width * random.random()
            y = self.height * random.random()
            size = 100 * random.random()
            
            self.food.append(Food(x, y, size))


    def initPlayers(self, nplayers):
        self.players = []
        
        for i in xrange(nplayers):
            x = self.width * random.random()
            y = self.height * random.random()
            self.players.append(Player(x, y, 10))
    

    def show(self):
        self.win = summon.Window("EAT!")
        
        # draw food
        vis = []
        for food in self.food:
            vis.append(food.draw())
        self.win.add_group(group(*vis))
        
        # draw players
        vis = []
        for player in self.players:
            for blob in player.blobs:
                vis.append(blob.draw())
        self.win.add_group(group(*vis))
        
        self.win.set_visible(self.players[0].cursor.x - 100, self.players[0].cursor.y - 100, 
                             self.players[0].cursor.x + 100, self.players[0].cursor.y + 100)
        
        #self.setVisible(True)
        
    
    def update(self):
        pass
        


game = EatGame()
game.show()
